@@ -4,11 +4,9 @@ from .asserts import *
 from .annotations import *
 from .classes.soft_assert import SoftAssert
 from .classes.fluent_assert import verify
+from .classes.spy import Spy
 
-# TODO docs, data_file (?),  csv_file(?)
-
-
-__all__ = ['start', 'common_parameters','SoftAssert',
+__all__ = ['start', 'common_parameters', 'SoftAssert', 'Spy',
            'equals', 'is_none', 'not_none', 'waiting_exception', 'test_fail', 'test_brake', 'no_exception_expected',
            'contains', 'verify', 'not_contains', 'not_equals', 'is_false', 'is_true', 'mock_builtins', 'mock',
            'test', 'before', 'after', 'before_group', 'after_group', 'before_suite', 'after_suite', 'data']
